pub struct MockProviderUsersApi {
ProviderUsersApi_expectations: MockProviderUsersApi_ProviderUsersApi,
}Fields
ProviderUsersApi_expectations: MockProviderUsersApi_ProviderUsersApiImplementations
Sourceimpl MockProviderUsersApi
impl MockProviderUsersApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockProviderUsersApi
impl MockProviderUsersApi
Sourcepub fn expect_accept(&mut self) -> &mut Expectation
pub fn expect_accept(&mut self) -> &mut Expectation
Create an Expectation for mocking the accept method
Sourcepub fn expect_bulk_confirm(&mut self) -> &mut Expectation
pub fn expect_bulk_confirm(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_confirm method
Sourcepub fn expect_bulk_delete(&mut self) -> &mut Expectation
pub fn expect_bulk_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_delete method
Sourcepub fn expect_bulk_reinvite(&mut self) -> &mut Expectation
pub fn expect_bulk_reinvite(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_reinvite method
Sourcepub fn expect_confirm(&mut self) -> &mut Expectation
pub fn expect_confirm(&mut self) -> &mut Expectation
Create an Expectation for mocking the confirm method
Sourcepub fn expect_delete(&mut self) -> &mut Expectation
pub fn expect_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_all(&mut self) -> &mut Expectation
pub fn expect_get_all(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_all method
Sourcepub fn expect_invite(&mut self) -> &mut Expectation
pub fn expect_invite(&mut self) -> &mut Expectation
Create an Expectation for mocking the invite method
Sourcepub fn expect_put(&mut self) -> &mut Expectation
pub fn expect_put(&mut self) -> &mut Expectation
Create an Expectation for mocking the put method
Sourcepub fn expect_reinvite(&mut self) -> &mut Expectation
pub fn expect_reinvite(&mut self) -> &mut Expectation
Create an Expectation for mocking the reinvite method
Sourcepub fn expect_user_public_keys(&mut self) -> &mut Expectation
pub fn expect_user_public_keys(&mut self) -> &mut Expectation
Create an Expectation for mocking the user_public_keys method